# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AggregatedNominationType(str, Enum):
    """
    AggregatedNominationType
    """

    """
    allowed enum values
    """
    TIMESCALE = 'TIMESCALE'
    TIMESCALE_AND_BPP = 'TIMESCALE_AND_BPP'
    BPP = 'BPP'
    SOSO = 'SOSO'
    OPERATIONAL_FLOW = 'OPERATIONAL_FLOW'

    @classmethod
    def from_json(cls, json_str: str) -> AggregatedNominationType:
        """Create an instance of AggregatedNominationType from a JSON string"""
        return AggregatedNominationType(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from datetime import date

from pydantic import Field, StrictStr, conlist

from typing import List, Optional

from empire_platform_api_public_client.models.auction_intra_day_product_type import AuctionIntraDayProductType
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.buy_now_day_ahead_offer_sort_by import BuyNowDayAheadOfferSortBy
from empire_platform_api_public_client.models.buy_now_offer import BuyNowOffer
from empire_platform_api_public_client.models.buy_now_offer_status import BuyNowOfferStatus

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class BuyNowOffersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_buy_now_offers(self, delivery_day : date, timescale : Annotated[AuctionTimescale, Field(..., description="Auction Timescale")], border_direction : Annotated[BorderDirection, Field(..., description="Border Direction")], statuses : conlist(BuyNowOfferStatus), sort_by : BuyNowDayAheadOfferSortBy, product_type : Annotated[Optional[AuctionIntraDayProductType], Field(description="Auction Product Type (ID only, optional)")] = None, **kwargs) -> List[BuyNowOffer]:  # noqa: E501
        """get_buy_now_offers  # noqa: E501

        Fetch a filterable, sortable list of Buy Now Offers  ---  __Requires Permission:__ (at least one)   * `VIEW_ANY_BUY_NOW_OFFERS`   * `VIEW_OWN_BUY_NOW_OFFERS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_buy_now_offers(delivery_day, timescale, border_direction, statuses, sort_by, product_type, async_req=True)
        >>> result = thread.get()

        :param delivery_day: (required)
        :type delivery_day: date
        :param timescale: Auction Timescale (required)
        :type timescale: AuctionTimescale
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param statuses: (required)
        :type statuses: List[BuyNowOfferStatus]
        :param sort_by: (required)
        :type sort_by: BuyNowDayAheadOfferSortBy
        :param product_type: Auction Product Type (ID only, optional)
        :type product_type: AuctionIntraDayProductType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[BuyNowOffer]
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_buy_now_offers_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_buy_now_offers_with_http_info(delivery_day, timescale, border_direction, statuses, sort_by, product_type, **kwargs)  # noqa: E501

    @validate_arguments
    def get_buy_now_offers_with_http_info(self, delivery_day : date, timescale : Annotated[AuctionTimescale, Field(..., description="Auction Timescale")], border_direction : Annotated[BorderDirection, Field(..., description="Border Direction")], statuses : conlist(BuyNowOfferStatus), sort_by : BuyNowDayAheadOfferSortBy, product_type : Annotated[Optional[AuctionIntraDayProductType], Field(description="Auction Product Type (ID only, optional)")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_buy_now_offers  # noqa: E501

        Fetch a filterable, sortable list of Buy Now Offers  ---  __Requires Permission:__ (at least one)   * `VIEW_ANY_BUY_NOW_OFFERS`   * `VIEW_OWN_BUY_NOW_OFFERS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_buy_now_offers_with_http_info(delivery_day, timescale, border_direction, statuses, sort_by, product_type, async_req=True)
        >>> result = thread.get()

        :param delivery_day: (required)
        :type delivery_day: date
        :param timescale: Auction Timescale (required)
        :type timescale: AuctionTimescale
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param statuses: (required)
        :type statuses: List[BuyNowOfferStatus]
        :param sort_by: (required)
        :type sort_by: BuyNowDayAheadOfferSortBy
        :param product_type: Auction Product Type (ID only, optional)
        :type product_type: AuctionIntraDayProductType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[BuyNowOffer], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'delivery_day',
            'timescale',
            'border_direction',
            'statuses',
            'sort_by',
            'product_type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_buy_now_offers" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('delivery_day') is not None:  # noqa: E501
            if isinstance(_params['delivery_day'], date):
                _query_params.append(('deliveryDay', _params['delivery_day'].isoformat()))
            else:
                _query_params.append(('deliveryDay', _params['delivery_day']))

        if _params.get('timescale') is not None:  # noqa: E501
            _query_params.append(('timescale', _params['timescale'].value))

        if _params.get('border_direction') is not None:  # noqa: E501
            _query_params.append(('borderDirection', _params['border_direction'].value))

        if _params.get('statuses') is not None:  # noqa: E501
            _query_params.append(('statuses', _params['statuses']))
            _collection_formats['statuses'] = 'multi'

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('product_type') is not None:  # noqa: E501
            _query_params.append(('productType', _params['product_type'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "List[BuyNowOffer]",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '409': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/buy-now-offers', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def purchase_buy_now_offer(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> None:  # noqa: E501
        """purchase_buy_now_offer  # noqa: E501

        Purchase an existing Buy Now Offer by its identifier  ---  __Requires Permission:__ (at least one)   * `PURCHASE_BUY_NOW_OFFERS`  __Generates Audit Log Entry:__ `PURCHASE_BUY_NOW_OFFER`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.purchase_buy_now_offer(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the purchase_buy_now_offer_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.purchase_buy_now_offer_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def purchase_buy_now_offer_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """purchase_buy_now_offer  # noqa: E501

        Purchase an existing Buy Now Offer by its identifier  ---  __Requires Permission:__ (at least one)   * `PURCHASE_BUY_NOW_OFFERS`  __Generates Audit Log Entry:__ `PURCHASE_BUY_NOW_OFFER`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.purchase_buy_now_offer_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method purchase_buy_now_offer" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/buy-now-offers/{id}/purchase', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.aggregated_nomination_options_nominee_participants import AggregatedNominationOptionsNomineeParticipants  # noqa: E501

class TestAggregatedNominationOptionsNomineeParticipants(unittest.TestCase):
    """AggregatedNominationOptionsNomineeParticipants unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AggregatedNominationOptionsNomineeParticipants:
        """Test AggregatedNominationOptionsNomineeParticipants
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AggregatedNominationOptionsNomineeParticipants`
        """
        model = AggregatedNominationOptionsNomineeParticipants()  # noqa: E501
        if include_optional:
            return AggregatedNominationOptionsNomineeParticipants(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = ''
            )
        else:
            return AggregatedNominationOptionsNomineeParticipants(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '',
        )
        """

    def testAggregatedNominationOptionsNomineeParticipants(self):
        """Test AggregatedNominationOptionsNomineeParticipants"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class BuyNowDayAheadOfferSortBy(str, Enum):
    """
    BuyNowDayAheadOfferSortBy
    """

    """
    allowed enum values
    """
    CAPACITY_ASC = 'CAPACITY_ASC'
    CAPACITY_DESC = 'CAPACITY_DESC'
    MOST_MTU_OFFERED_ASC = 'MOST_MTU_OFFERED_ASC'
    MOST_MTU_OFFERED_DESC = 'MOST_MTU_OFFERED_DESC'
    PRICE_ASC = 'PRICE_ASC'
    PRICE_DESC = 'PRICE_DESC'
    TIME_LEFT_ASC = 'TIME_LEFT_ASC'
    TIME_LEFT_DESC = 'TIME_LEFT_DESC'

    @classmethod
    def from_json(cls, json_str: str) -> BuyNowDayAheadOfferSortBy:
        """Create an instance of BuyNowDayAheadOfferSortBy from a JSON string"""
        return BuyNowDayAheadOfferSortBy(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.aggregated_nominations_nl import AggregatedNominationsNl  # noqa: E501

class TestAggregatedNominationsNl(unittest.TestCase):
    """AggregatedNominationsNl unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AggregatedNominationsNl:
        """Test AggregatedNominationsNl
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AggregatedNominationsNl`
        """
        model = AggregatedNominationsNl()  # noqa: E501
        if include_optional:
            return AggregatedNominationsNl(
                mtu_size = 'MTU_15_MINS',
                mtus = [
                    empire_platform_api_public_client.models.aggregated_nominations_nl_mtus.AggregatedNominationsNl_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.aggregated_nominations_mtu_value.AggregatedNominationsMtuValue(
                                direction = 'GB_NL', 
                                value = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.aggregated_nominations_mtu_netted_nominations.AggregatedNominationsMtuNettedNominations(
                            direction = 'GB_NL', 
                            flow = 56, ), 
                        eprogram_values = empire_platform_api_public_client.models.aggregated_nominations_nl_mtus_eprogram_values.AggregatedNominationsNl_mtus_eprogramValues(
                            participant = 56, 
                            system = 56, ), )
                    ]
            )
        else:
            return AggregatedNominationsNl(
                mtu_size = 'MTU_15_MINS',
                mtus = [
                    empire_platform_api_public_client.models.aggregated_nominations_nl_mtus.AggregatedNominationsNl_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.aggregated_nominations_mtu_value.AggregatedNominationsMtuValue(
                                direction = 'GB_NL', 
                                value = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.aggregated_nominations_mtu_netted_nominations.AggregatedNominationsMtuNettedNominations(
                            direction = 'GB_NL', 
                            flow = 56, ), 
                        eprogram_values = empire_platform_api_public_client.models.aggregated_nominations_nl_mtus_eprogram_values.AggregatedNominationsNl_mtus_eprogramValues(
                            participant = 56, 
                            system = 56, ), )
                    ],
        )
        """

    def testAggregatedNominationsNl(self):
        """Test AggregatedNominationsNl"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid import DayAheadOrIntraDayDefaultBid  # noqa: E501

class TestDayAheadOrIntraDayDefaultBid(unittest.TestCase):
    """DayAheadOrIntraDayDefaultBid unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DayAheadOrIntraDayDefaultBid:
        """Test DayAheadOrIntraDayDefaultBid
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayDefaultBid`
        """
        model = DayAheadOrIntraDayDefaultBid()  # noqa: E501
        if include_optional:
            return DayAheadOrIntraDayDefaultBid(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                delivery_period_start = '2022-01-04T10:00Z',
                delivery_period_end = '2022-01-04T11:00Z',
                validity_period_start = '2022-01-04T00:00Z',
                validity_period_end = '2022-01-04T00:00Z',
                mtu_size = 'MTU_15_MINS',
                bids = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids.DayAheadOrIntraDayDefaultBid_bids(
                        mtus = [
                            empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids_mtus.DayAheadOrIntraDayDefaultBid_bids_mtus(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ]
            )
        else:
            return DayAheadOrIntraDayDefaultBid(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                delivery_period_start = '2022-01-04T10:00Z',
                validity_period_start = '2022-01-04T00:00Z',
                mtu_size = 'MTU_15_MINS',
                bids = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids.DayAheadOrIntraDayDefaultBid_bids(
                        mtus = [
                            empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids_mtus.DayAheadOrIntraDayDefaultBid_bids_mtus(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ],
        )
        """

    def testDayAheadOrIntraDayDefaultBid(self):
        """Test DayAheadOrIntraDayDefaultBid"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuctionIntraDayProductType(str, Enum):
    """
    AuctionIntraDayProductType
    """

    """
    allowed enum values
    """
    ID_EXPLICIT_ID_1 = 'ID_EXPLICIT_ID_1'
    ID_EXPLICIT_ID_2 = 'ID_EXPLICIT_ID_2'
    ID_EXPLICIT_ID_3 = 'ID_EXPLICIT_ID_3'
    ID_EXPLICIT_ID_4 = 'ID_EXPLICIT_ID_4'

    @classmethod
    def from_json(cls, json_str: str) -> AuctionIntraDayProductType:
        """Create an instance of AuctionIntraDayProductType from a JSON string"""
        return AuctionIntraDayProductType(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictInt, confloat, conint

class BiddingConfigurationPerDirection(BaseModel):
    """
    BiddingConfigurationPerDirection
    """
    maximum_bid_capacity: Optional[StrictInt] = Field(None, alias="maximumBidCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    warning_bid_price: Optional[Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)]] = Field(None, alias="warningBidPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    maximum_bid_price: Optional[Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)]] = Field(None, alias="maximumBidPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    __properties = ["maximumBidCapacity", "warningBidPrice", "maximumBidPrice"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BiddingConfigurationPerDirection:
        """Create an instance of BiddingConfigurationPerDirection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BiddingConfigurationPerDirection:
        """Create an instance of BiddingConfigurationPerDirection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BiddingConfigurationPerDirection.parse_obj(obj)

        _obj = BiddingConfigurationPerDirection.parse_obj({
            "maximum_bid_capacity": obj.get("maximumBidCapacity"),
            "warning_bid_price": obj.get("warningBidPrice"),
            "maximum_bid_price": obj.get("maximumBidPrice")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from empire_platform_api_public_client.models.border_direction_with_both_and_none import BorderDirectionWithBothAndNone
from empire_platform_api_public_client.models.timescale_nomination_options_window_timing import TimescaleNominationOptionsWindowTiming
from empire_platform_api_public_client.models.timescale_nomination_window_status import TimescaleNominationWindowStatus

class TimescaleNominationOptions(BaseModel):
    """
    TimescaleNominationOptions
    """
    window_timing: Optional[TimescaleNominationOptionsWindowTiming] = Field(None, alias="windowTiming")
    window_status: TimescaleNominationWindowStatus = Field(..., alias="windowStatus")
    rights_in_directions: BorderDirectionWithBothAndNone = Field(..., alias="rightsInDirections")
    __properties = ["windowTiming", "windowStatus", "rightsInDirections"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TimescaleNominationOptions:
        """Create an instance of TimescaleNominationOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of window_timing
        if self.window_timing:
            _dict['windowTiming'] = self.window_timing.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TimescaleNominationOptions:
        """Create an instance of TimescaleNominationOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TimescaleNominationOptions.parse_obj(obj)

        _obj = TimescaleNominationOptions.parse_obj({
            "window_timing": TimescaleNominationOptionsWindowTiming.from_dict(obj.get("windowTiming")) if obj.get("windowTiming") is not None else None,
            "window_status": obj.get("windowStatus"),
            "rights_in_directions": obj.get("rightsInDirections")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.organisation_document_api import OrganisationDocumentApi  # noqa: E501


class TestOrganisationDocumentApi(unittest.TestCase):
    """OrganisationDocumentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganisationDocumentApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_create_organisation_document(self) -> None:
        """Test case for create_organisation_document

        """
        pass

    def test_delete_organisation_document(self) -> None:
        """Test case for delete_organisation_document

        """
        pass

    def test_get_organisation_document_options(self) -> None:
        """Test case for get_organisation_document_options

        """
        pass

    def test_get_organisation_documents(self) -> None:
        """Test case for get_organisation_documents

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictInt, StrictStr, confloat, conint, constr, validator

class SecondaryMarketLongTermNoticeboardEntryResponse(BaseModel):
    """
    SecondaryMarketLongTermNoticeboardEntryResponse
    """
    reponse_capacity: StrictInt = Field(..., alias="reponseCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    response_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="responsePrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    contact_name: StrictStr = Field(..., alias="contactName")
    phone_number: constr(strict=True) = Field(..., alias="phoneNumber")
    email: constr(strict=True) = Field(...)
    comment: Optional[StrictStr] = None
    responded_at: datetime = Field(..., alias="respondedAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["reponseCapacity", "responsePrice", "contactName", "phoneNumber", "email", "comment", "respondedAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SecondaryMarketLongTermNoticeboardEntryResponse:
        """Create an instance of SecondaryMarketLongTermNoticeboardEntryResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SecondaryMarketLongTermNoticeboardEntryResponse:
        """Create an instance of SecondaryMarketLongTermNoticeboardEntryResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SecondaryMarketLongTermNoticeboardEntryResponse.parse_obj(obj)

        _obj = SecondaryMarketLongTermNoticeboardEntryResponse.parse_obj({
            "reponse_capacity": obj.get("reponseCapacity"),
            "response_price": obj.get("responsePrice"),
            "contact_name": obj.get("contactName"),
            "phone_number": obj.get("phoneNumber"),
            "email": obj.get("email"),
            "comment": obj.get("comment"),
            "responded_at": obj.get("respondedAt")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_matching import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching  # noqa: E501

class TestSecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching(unittest.TestCase):
    """SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching:
        """Test SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching`
        """
        model = SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching()  # noqa: E501
        if include_optional:
            return SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                type = 'BUY',
                delivery_day_from = 'Tue Jan 04 00:00:00 UTC 2022',
                delivery_day_to = 'Tue Jan 04 00:00:00 UTC 2022',
                timescale = 'LONG_TERM',
                direction = 'GB_NL',
                posted_at = '2022-01-04T00:00Z',
                expires_at = '2022-01-04T00:00Z',
                matching_percentage = 0
            )
        else:
            return SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                type = 'BUY',
                delivery_day_from = 'Tue Jan 04 00:00:00 UTC 2022',
                delivery_day_to = 'Tue Jan 04 00:00:00 UTC 2022',
                timescale = 'LONG_TERM',
                direction = 'GB_NL',
                posted_at = '2022-01-04T00:00Z',
                expires_at = '2022-01-04T00:00Z',
                matching_percentage = 0,
        )
        """

    def testSecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching(self):
        """Test SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from empire_platform_api_public_client.models.attachment import Attachment
from empire_platform_api_public_client.models.invoice_status import InvoiceStatus

class ParticipantDashboardFinanceOverviewInvoice(BaseModel):
    """
    ParticipantDashboardFinanceOverviewInvoice
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    display_id: StrictStr = Field(..., alias="displayId")
    status: InvoiceStatus = Field(...)
    attachment: Optional[Attachment] = None
    due_date: Optional[date] = Field(None, alias="dueDate", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    payment_date: Optional[date] = Field(None, alias="paymentDate", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    __properties = ["id", "displayId", "status", "attachment", "dueDate", "paymentDate"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantDashboardFinanceOverviewInvoice:
        """Create an instance of ParticipantDashboardFinanceOverviewInvoice from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of attachment
        if self.attachment:
            _dict['attachment'] = self.attachment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantDashboardFinanceOverviewInvoice:
        """Create an instance of ParticipantDashboardFinanceOverviewInvoice from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantDashboardFinanceOverviewInvoice.parse_obj(obj)

        _obj = ParticipantDashboardFinanceOverviewInvoice.parse_obj({
            "id": obj.get("id"),
            "display_id": obj.get("displayId"),
            "status": obj.get("status"),
            "attachment": Attachment.from_dict(obj.get("attachment")) if obj.get("attachment") is not None else None,
            "due_date": obj.get("dueDate"),
            "payment_date": obj.get("paymentDate")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids import DayAheadOrIntraDayAuctionBidGroupBids  # noqa: E501

class TestDayAheadOrIntraDayAuctionBidGroupBids(unittest.TestCase):
    """DayAheadOrIntraDayAuctionBidGroupBids unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DayAheadOrIntraDayAuctionBidGroupBids:
        """Test DayAheadOrIntraDayAuctionBidGroupBids
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayAuctionBidGroupBids`
        """
        model = DayAheadOrIntraDayAuctionBidGroupBids()  # noqa: E501
        if include_optional:
            return DayAheadOrIntraDayAuctionBidGroupBids(
                mtu = '2022-01-04T10:00Z',
                bid = empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_bid.DayAheadOrIntraDayAuctionBidGroup_bids_bid(
                    value = empire_platform_api_public_client.models.bid_value.BidValue(
                        price = 1.337, 
                        capacity = 56, ), 
                    updated_at = '2022-01-04T00:00Z', 
                    status = 'NOT_CLEARED_YET', 
                    results = empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_bid_results.DayAheadOrIntraDayAuctionBidGroup_bids_bid_results(
                        allocated_capacity = 56, 
                        marginal_price = 1.337, ), )
            )
        else:
            return DayAheadOrIntraDayAuctionBidGroupBids(
                mtu = '2022-01-04T10:00Z',
        )
        """

    def testDayAheadOrIntraDayAuctionBidGroupBids(self):
        """Test DayAheadOrIntraDayAuctionBidGroupBids"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from empire_platform_api_public_client.models.finance_information_lockable_amount import FinanceInformationLockableAmount
from empire_platform_api_public_client.models.finance_information_lockable_date import FinanceInformationLockableDate

class FinanceInformationLockablePeriod(BaseModel):
    """
    FinanceInformationLockablePeriod
    """
    validity_from: FinanceInformationLockableDate = Field(..., alias="validityFrom")
    validity_to: FinanceInformationLockableDate = Field(..., alias="validityTo")
    amount: FinanceInformationLockableAmount = Field(...)
    __properties = ["validityFrom", "validityTo", "amount"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FinanceInformationLockablePeriod:
        """Create an instance of FinanceInformationLockablePeriod from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of validity_from
        if self.validity_from:
            _dict['validityFrom'] = self.validity_from.to_dict()
        # override the default output from pydantic by calling `to_dict()` of validity_to
        if self.validity_to:
            _dict['validityTo'] = self.validity_to.to_dict()
        # override the default output from pydantic by calling `to_dict()` of amount
        if self.amount:
            _dict['amount'] = self.amount.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FinanceInformationLockablePeriod:
        """Create an instance of FinanceInformationLockablePeriod from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FinanceInformationLockablePeriod.parse_obj(obj)

        _obj = FinanceInformationLockablePeriod.parse_obj({
            "validity_from": FinanceInformationLockableDate.from_dict(obj.get("validityFrom")) if obj.get("validityFrom") is not None else None,
            "validity_to": FinanceInformationLockableDate.from_dict(obj.get("validityTo")) if obj.get("validityTo") is not None else None,
            "amount": FinanceInformationLockableAmount.from_dict(obj.get("amount")) if obj.get("amount") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from empire_platform_api_public_client.models.bid_value import BidValue

class SubmitLongTermBidsRequestBids(BaseModel):
    """
    SubmitLongTermBidsRequestBids
    """
    id: Optional[StrictStr] = Field(None, description="Unique (at least locally) identifier for the record in UUID4 format  * records received nullable identifiers through GET requests should have the property filled out * records sent to PUT endpoints:   - if property is filled out => backend is expected to update the record   - if property is null or missing => backend is expected to create a new record   - if list of records does not contain the record identifier => backend is expected to delete the record ")
    external_id: Optional[StrictStr] = Field(None, alias="externalId", description="Optional external identifier for the bid, for example to differentiate between traders ")
    value: BidValue = Field(...)
    __properties = ["id", "externalId", "value"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SubmitLongTermBidsRequestBids:
        """Create an instance of SubmitLongTermBidsRequestBids from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of value
        if self.value:
            _dict['value'] = self.value.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SubmitLongTermBidsRequestBids:
        """Create an instance of SubmitLongTermBidsRequestBids from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SubmitLongTermBidsRequestBids.parse_obj(obj)

        _obj = SubmitLongTermBidsRequestBids.parse_obj({
            "id": obj.get("id"),
            "external_id": obj.get("externalId"),
            "value": BidValue.from_dict(obj.get("value")) if obj.get("value") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.participant_dashboard_next_auction import ParticipantDashboardNextAuction  # noqa: E501

class TestParticipantDashboardNextAuction(unittest.TestCase):
    """ParticipantDashboardNextAuction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardNextAuction:
        """Test ParticipantDashboardNextAuction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardNextAuction`
        """
        model = ParticipantDashboardNextAuction()  # noqa: E501
        if include_optional:
            return ParticipantDashboardNextAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '2022 May Auction',
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                status = 'CREATED',
                pre_bidding_allowed = True,
                bids_count = 0,
                offered_capacity = 56,
                next_action_at = '2022-01-04T00:00Z'
            )
        else:
            return ParticipantDashboardNextAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '2022 May Auction',
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                status = 'CREATED',
                pre_bidding_allowed = True,
                bids_count = 0,
        )
        """

    def testParticipantDashboardNextAuction(self):
        """Test ParticipantDashboardNextAuction"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.settlement_per_source import SettlementPerSource  # noqa: E501

class TestSettlementPerSource(unittest.TestCase):
    """SettlementPerSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SettlementPerSource:
        """Test SettlementPerSource
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SettlementPerSource`
        """
        model = SettlementPerSource()  # noqa: E501
        if include_optional:
            return SettlementPerSource(
                source = 'AUCTION',
                sub_source = 'EXPLICIT_AUCTION_MULTI_ANNUAL',
                total_amount = 1.337,
                values = [
                    empire_platform_api_public_client.models.settlement_item.SettlementItem(
                        direction = 'GB_NL', 
                        transmission_rights = 56, 
                        amount = 1.337, )
                    ]
            )
        else:
            return SettlementPerSource(
                source = 'AUCTION',
                sub_source = 'EXPLICIT_AUCTION_MULTI_ANNUAL',
                total_amount = 1.337,
                values = [
                    empire_platform_api_public_client.models.settlement_item.SettlementItem(
                        direction = 'GB_NL', 
                        transmission_rights = 56, 
                        amount = 1.337, )
                    ],
        )
        """

    def testSettlementPerSource(self):
        """Test SettlementPerSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_transfer_request_mtus import CreateSecondaryMarketDayAheadOrIntraDayTransferRequestMtus

class CreateSecondaryMarketDayAheadOrIntraDayTransferRequest(BaseModel):
    """
    CreateSecondaryMarketDayAheadOrIntraDayTransferRequest
    """
    delivery_day: date = Field(..., alias="deliveryDay", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    direction: BorderDirection = Field(...)
    participant_id: StrictStr = Field(..., alias="participantId", description="Unique identifier for the record in UUID4 format")
    timescale: AuctionTimescale = Field(...)
    mtus: conlist(CreateSecondaryMarketDayAheadOrIntraDayTransferRequestMtus) = Field(...)
    __properties = ["deliveryDay", "direction", "participantId", "timescale", "mtus"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateSecondaryMarketDayAheadOrIntraDayTransferRequest:
        """Create an instance of CreateSecondaryMarketDayAheadOrIntraDayTransferRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in mtus (list)
        _items = []
        if self.mtus:
            for _item in self.mtus:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mtus'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateSecondaryMarketDayAheadOrIntraDayTransferRequest:
        """Create an instance of CreateSecondaryMarketDayAheadOrIntraDayTransferRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateSecondaryMarketDayAheadOrIntraDayTransferRequest.parse_obj(obj)

        _obj = CreateSecondaryMarketDayAheadOrIntraDayTransferRequest.parse_obj({
            "delivery_day": obj.get("deliveryDay"),
            "direction": obj.get("direction"),
            "participant_id": obj.get("participantId"),
            "timescale": obj.get("timescale"),
            "mtus": [CreateSecondaryMarketDayAheadOrIntraDayTransferRequestMtus.from_dict(_item) for _item in obj.get("mtus")] if obj.get("mtus") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conint, conlist
from empire_platform_api_public_client.models.organisation_user import OrganisationUser

class OrganisationUserBatch(BaseModel):
    """
    OrganisationUserBatch
    """
    entries: conlist(OrganisationUser) = Field(...)
    total_count: conint(strict=True, ge=0) = Field(..., alias="totalCount", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    __properties = ["entries", "totalCount"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrganisationUserBatch:
        """Create an instance of OrganisationUserBatch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in entries (list)
        _items = []
        if self.entries:
            for _item in self.entries:
                if _item:
                    _items.append(_item.to_dict())
            _dict['entries'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrganisationUserBatch:
        """Create an instance of OrganisationUserBatch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrganisationUserBatch.parse_obj(obj)

        _obj = OrganisationUserBatch.parse_obj({
            "entries": [OrganisationUser.from_dict(_item) for _item in obj.get("entries")] if obj.get("entries") is not None else None,
            "total_count": obj.get("totalCount")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictBool

class OrganisationFileSettings(BaseModel):
    """
    OrganisationFileSettings
    """
    include_in_fpn: StrictBool = Field(..., alias="includeInFpn")
    include_in_dmv: StrictBool = Field(..., alias="includeInDmv")
    __properties = ["includeInFpn", "includeInDmv"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrganisationFileSettings:
        """Create an instance of OrganisationFileSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrganisationFileSettings:
        """Create an instance of OrganisationFileSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrganisationFileSettings.parse_obj(obj)

        _obj = OrganisationFileSettings.parse_obj({
            "include_in_fpn": obj.get("includeInFpn"),
            "include_in_dmv": obj.get("includeInDmv")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results import DayAheadOrIntraDayAuctionResults  # noqa: E501

class TestDayAheadOrIntraDayAuctionResults(unittest.TestCase):
    """DayAheadOrIntraDayAuctionResults unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DayAheadOrIntraDayAuctionResults:
        """Test DayAheadOrIntraDayAuctionResults
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayAuctionResults`
        """
        model = DayAheadOrIntraDayAuctionResults()  # noqa: E501
        if include_optional:
            return DayAheadOrIntraDayAuctionResults(
                congestion_rent = empire_platform_api_public_client.models.auction_result_congestion_rent.AuctionResultCongestionRent(
                    oc_revenue = 1.337, 
                    returns_revenue = 1.337, 
                    total_revenue = 1.337, ),
                mtus = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results_mtu.DayAheadOrIntraDayAuctionResultsMtu(
                        mtu = '2022-01-04T10:00Z', 
                        requested_capacity = 56, 
                        allocated_trs = 56, 
                        marginal_price = 1.337, 
                        participant_count = 0, 
                        successful_participant_count = 0, 
                        bid_count = 0, )
                    ],
                successful_participants = [
                    empire_platform_api_public_client.models.auction_result_participant.AuctionResultParticipant(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', 
                        eic_code = '---7S--058SL--92', )
                    ]
            )
        else:
            return DayAheadOrIntraDayAuctionResults(
                mtus = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results_mtu.DayAheadOrIntraDayAuctionResultsMtu(
                        mtu = '2022-01-04T10:00Z', 
                        requested_capacity = 56, 
                        allocated_trs = 56, 
                        marginal_price = 1.337, 
                        participant_count = 0, 
                        successful_participant_count = 0, 
                        bid_count = 0, )
                    ],
                successful_participants = [
                    empire_platform_api_public_client.models.auction_result_participant.AuctionResultParticipant(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', 
                        eic_code = '---7S--058SL--92', )
                    ],
        )
        """

    def testDayAheadOrIntraDayAuctionResults(self):
        """Test DayAheadOrIntraDayAuctionResults"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.invoice_details import InvoiceDetails  # noqa: E501

class TestInvoiceDetails(unittest.TestCase):
    """InvoiceDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoiceDetails:
        """Test InvoiceDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoiceDetails`
        """
        model = InvoiceDetails()  # noqa: E501
        if include_optional:
            return InvoiceDetails(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                display_id = '',
                participant = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', ),
                period = empire_platform_api_public_client.models.date_period.DatePeriod(
                    start = 'Tue Jan 04 00:00:00 UTC 2022', 
                    end = 'Tue Jan 04 00:00:00 UTC 2022', ),
                net_amount = 1.337,
                gross_amount = 1.337,
                due_date = 'Tue Jan 04 00:00:00 UTC 2022',
                sent_date = 'Tue Jan 04 00:00:00 UTC 2022',
                paid_date = 'Tue Jan 04 00:00:00 UTC 2022',
                status = 'DRAFT',
                last_status_change = '2022-01-04T00:00Z',
                sendable = True,
                line_items = [
                    empire_platform_api_public_client.models.invoice_line_item.InvoiceLineItem(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        code = 'NL_GB_EXPLICIT_ANNUAL_AUCTIONS', 
                        direction = 'GB_NL', 
                        delivery_month = 'Sat Jan 01 00:00:00 UTC 2022', 
                        net_amount = 1.337, 
                        vat_rate = 0, 
                        vat_amount = 1.337, 
                        gross_amount = 1.337, 
                        manually_added = True, )
                    ],
                vat_rates = [
                    empire_platform_api_public_client.models.invoice_vat_rate.InvoiceVatRate(
                        direction = 'GB_NL', 
                        vat_rate = 0, )
                    ],
                summaries = [
                    empire_platform_api_public_client.models.invoice_summary.InvoiceSummary(
                        direction = 'GB_NL', 
                        net_amount = 1.337, 
                        net_amount_gbp = 1.337, 
                        vat_amount = 1.337, 
                        vat_amount_gbp = 1.337, 
                        exchange_rate = 1.337, 
                        exchange_rate_day = 'Tue Jan 04 00:00:00 UTC 2022', )
                    ],
                attachment = empire_platform_api_public_client.models.attachment.Attachment(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    file_name = '', 
                    file_size = 0, 
                    mime_type = '', 
                    url = '', ),
                history = [
                    empire_platform_api_public_client.models.invoice_history.InvoiceHistory(
                        user = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        action = 'GENERATED', 
                        actioned_at = '2022-01-04T00:00Z', )
                    ]
            )
        else:
            return InvoiceDetails(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                display_id = '',
                participant = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', ),
                period = empire_platform_api_public_client.models.date_period.DatePeriod(
                    start = 'Tue Jan 04 00:00:00 UTC 2022', 
                    end = 'Tue Jan 04 00:00:00 UTC 2022', ),
                net_amount = 1.337,
                gross_amount = 1.337,
                status = 'DRAFT',
                last_status_change = '2022-01-04T00:00Z',
                sendable = True,
                line_items = [
                    empire_platform_api_public_client.models.invoice_line_item.InvoiceLineItem(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        code = 'NL_GB_EXPLICIT_ANNUAL_AUCTIONS', 
                        direction = 'GB_NL', 
                        delivery_month = 'Sat Jan 01 00:00:00 UTC 2022', 
                        net_amount = 1.337, 
                        vat_rate = 0, 
                        vat_amount = 1.337, 
                        gross_amount = 1.337, 
                        manually_added = True, )
                    ],
                vat_rates = [
                    empire_platform_api_public_client.models.invoice_vat_rate.InvoiceVatRate(
                        direction = 'GB_NL', 
                        vat_rate = 0, )
                    ],
                summaries = [
                    empire_platform_api_public_client.models.invoice_summary.InvoiceSummary(
                        direction = 'GB_NL', 
                        net_amount = 1.337, 
                        net_amount_gbp = 1.337, 
                        vat_amount = 1.337, 
                        vat_amount_gbp = 1.337, 
                        exchange_rate = 1.337, 
                        exchange_rate_day = 'Tue Jan 04 00:00:00 UTC 2022', )
                    ],
                history = [
                    empire_platform_api_public_client.models.invoice_history.InvoiceHistory(
                        user = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        action = 'GENERATED', 
                        actioned_at = '2022-01-04T00:00Z', )
                    ],
        )
        """

    def testInvoiceDetails(self):
        """Test InvoiceDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data import ParticipantDashboardNettedNominationsData  # noqa: E501

class TestParticipantDashboardNettedNominationsData(unittest.TestCase):
    """ParticipantDashboardNettedNominationsData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardNettedNominationsData:
        """Test ParticipantDashboardNettedNominationsData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardNettedNominationsData`
        """
        model = ParticipantDashboardNettedNominationsData()  # noqa: E501
        if include_optional:
            return ParticipantDashboardNettedNominationsData(
                mtu_size = 'MTU_15_MINS',
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus.ParticipantDashboardNettedNominationsData_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        aggregated_nominations = [
                            empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_aggregated_nominations.ParticipantDashboardNettedNominationsData_mtus_aggregatedNominations(
                                direction = 'GB_NL', 
                                value = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_netted_nominations.ParticipantDashboardNettedNominationsData_mtus_nettedNominations(
                            flow = 56, 
                            direction = 'GB_NL', ), )
                    ]
            )
        else:
            return ParticipantDashboardNettedNominationsData(
                mtu_size = 'MTU_15_MINS',
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus.ParticipantDashboardNettedNominationsData_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        aggregated_nominations = [
                            empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_aggregated_nominations.ParticipantDashboardNettedNominationsData_mtus_aggregatedNominations(
                                direction = 'GB_NL', 
                                value = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_netted_nominations.ParticipantDashboardNettedNominationsData_mtus_nettedNominations(
                            flow = 56, 
                            direction = 'GB_NL', ), )
                    ],
        )
        """

    def testParticipantDashboardNettedNominationsData(self):
        """Test ParticipantDashboardNettedNominationsData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
